Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2979)

Unified Diff: chrome/browser/sync/glue/ui_data_type_controller.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/ui_data_type_controller.h
diff --git a/chrome/browser/sync/glue/ui_data_type_controller.h b/chrome/browser/sync/glue/ui_data_type_controller.h
index 8120f58e5d2250eb88605de096fe53354ca25965..9bbc7536cd053d73134250c0d0c6ccfe377a2ad0 100644
--- a/chrome/browser/sync/glue/ui_data_type_controller.h
+++ b/chrome/browser/sync/glue/ui_data_type_controller.h
@@ -23,7 +23,7 @@ namespace base {
class TimeDelta;
}
-namespace csync {
+namespace syncer {
class SyncableService;
class SyncError;
}
@@ -48,7 +48,7 @@ class UIDataTypeController : public DataTypeController {
virtual void StartAssociating(const StartCallback& start_callback) OVERRIDE;
virtual void Stop() OVERRIDE;
virtual syncable::ModelType type() const OVERRIDE;
- virtual csync::ModelSafeGroup model_safe_group() const OVERRIDE;
+ virtual syncer::ModelSafeGroup model_safe_group() const OVERRIDE;
virtual std::string name() const OVERRIDE;
virtual State state() const OVERRIDE;
@@ -79,7 +79,7 @@ class UIDataTypeController : public DataTypeController {
virtual void OnModelLoaded() OVERRIDE;
// Helper methods for cleaning up state and invoking the start callback.
- virtual void StartFailed(StartResult result, const csync::SyncError& error);
+ virtual void StartFailed(StartResult result, const syncer::SyncError& error);
virtual void StartDone(StartResult result);
// Record association time.
@@ -110,7 +110,7 @@ class UIDataTypeController : public DataTypeController {
//
// Note: we use refcounting here primarily so that we can keep a uniform
// SyncableService API, whether the datatype lives on the UI thread or not
// (a csync::SyncableService takes ownership of its SyncChangeProcessor when
// MergeDataAndStartSyncing is called). This will help us eventually merge the
// two datatype controller implementations (for ui and non-ui thread
// datatypes).
@@ -118,7 +118,7 @@ class UIDataTypeController : public DataTypeController {
// A weak pointer to the actual local syncable service, which performs all the
// real work. We do not own the object.
- base::WeakPtr<csync::SyncableService> local_service_;
+ base::WeakPtr<syncer::SyncableService> local_service_;
private:
// Associate the sync model with the service's model, then start syncing.
« no previous file with comments | « chrome/browser/sync/glue/typed_url_model_associator_unittest.cc ('k') | chrome/browser/sync/glue/ui_data_type_controller.cc » ('j') | no next file with comments »
@@ -110,7 +110,7 @@ class UIDataTypeController : public DataTypeController {
// Note: we use refcounting here primarily so that we can keep a uniform
// SyncableService API, whether the datatype lives on the UI thread or not
- // (a csync::SyncableService takes ownership of its SyncChangeProcessor when
+ // (a syncer::SyncableService takes ownership of its SyncChangeProcessor when
// MergeDataAndStartSyncing is called). This will help us eventually merge the
// two datatype controller implementations (for ui and non-ui thread

Powered by Google App Engine
This is Rietveld 408576698